@@ -4,7 +4,7 @@ from typing import List, Optional
 
 def parse_args() -> argparse.Namespace:
     """
-    Parse command‑line arguments for the A2A server.
+    Parse command-line arguments for the A2A server.
     """
     parser = argparse.ArgumentParser("A2A Server (YAML config)")
     parser.add_argument(
@@ -37,4 +37,10 @@ def parse_args() -> argparse.Namespace:
         action="store_true",
         help="Enable detailed flow diagnosis and tracing"
     )
-    return parser.parse_args()
+    # Added argument for session support
+    parser.add_argument(
+        "--enable-sessions",
+        action="store_true",
+        help="Enable conversation session tracking with chuk-session-manager"
+    )
+    return parser.parse_args()
\ No newline at end of file
